import{R as t}from"./Title.c70c7e79.js";import{F as n}from"./outputWidgets.d94fff8c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="901f9254-ce27-46a3-811f-6c6f06d9f9f5",e._sentryDebugIdIdentifier="sentry-dbid-901f9254-ce27-46a3-811f-6c6f06d9f9f5")}catch{}})();const s=n(t);export{s as A};
//# sourceMappingURL=index.3709b59d.js.map
