import{d as g,ez as v,eA as b,r as k,b as r,c as s,w as a,u as e,f as u,ew as n}from"./outputWidgets.d94fff8c.js";import{S as h,L as w}from"./SmartConsole.4ccb77f1.js";import{a as x}from"./asyncComputed.6da48dd7.js";import{H as B}from"./hooks.0a2d0d18.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.00be30ea.js";import{_ as H}from"./DocsButton.vue_vue_type_script_setup_true_lang.21d0d4fe.js";import{B as I}from"./BaseLayout.f1c5ada3.js";import{_ as S,a as T}from"./HookSettings.vue_vue_type_script_setup_true_lang.471aa574.js";import{c as A}from"./index.c81cf59e.js";import{A as _,T as D}from"./TabPane.71415757.js";import"./forms.6cfc05eb.js";import"./activeRecord.4bb9e983.js";import"./pubsub.39314a92.js";import"./dashes.8c8e25c6.js";import"./index.3dad0da1.js";import"./jobs.314c73b6.js";import"./workspaces.c4438eba.js";import"./url.596d80c9.js";import"./icons.fec42461.js";import"./Title.c70c7e79.js";import"./index.3709b59d.js";import"./uuid.fd17a681.js";import"./ant-design.b0e50c8b.js";import"./StageRunSelector.vue_vue_type_script_setup_true_lang.9631319b.js";import"./RunButton.vue_vue_type_script_setup_true_lang.d2d28986.js";import"./index.4982fa60.js";import"./index.0f14f01f.js";import"./CollapsePanel.1d546a09.js";import"./index.209f6c1c.js";import"./index.0e652438.js";import"./index.e7f021ad.js";import"./Form.57801503.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="d37959e8-8046-4560-a753-b584fc5dc718",i._sentryDebugIdIdentifier="sentry-dbid-d37959e8-8046-4560-a753-b584fc5dc718")}catch{}})();const le=g({__name:"HookEditor",setup(i){const m=v(),l=b(),c=k(null),o=k("test");function y(){m.push({name:"hooks"})}const{result:t}=x(()=>B.get(l.params.hookPath)),f=w.create();return(R,d)=>(r(),s(I,null,{navbar:a(()=>[e(t)?(r(),s(e(A),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[u(e(D),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=p=>o.value=p)},{default:a(()=>[u(e(_),{key:"test",tab:"Test"}),u(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[u(H,{path:"hooks"}),o.value==="settings"?(r(),s(C,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(S,{key:0,ref_key:"tester",ref:c,hook:e(t),"log-service":e(f)},null,8,["hook","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),s(T,{key:1,hook:e(t)},null,8,["hook"])):n("",!0)]),footer:a(()=>{var p;return[e(t)&&o.value==="test"?(r(),s(h,{key:0,runtime:"forms","log-service":e(f),onRestart:(p=c.value)==null?void 0:p.runHook},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{le as default};
//# sourceMappingURL=HookEditor.946d46e6.js.map
