import{cG as n}from"./outputWidgets.d94fff8c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="f0280a30-e4b9-45e4-938a-075b639a1695",e._sentryDebugIdIdentifier="sentry-dbid-f0280a30-e4b9-45e4-938a-075b639a1695")}catch{}})();const d=(e,r)=>{n.error({message:e,description:r})};export{d as p};
//# sourceMappingURL=popupNotifcation.95da5c51.js.map
