[data-v-fd903d79]:root{--main-font-family: DM Sans, sans-serif}[data-v-fd903d79]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-fd903d79]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-fd903d79]{background-color:#fff;padding:10px}.row-itens-container[data-v-fd903d79]{display:flex;justify-content:space-between;width:100%}.row-itens-container>*[data-v-fd903d79]{width:25%}html,body{overscroll-behavior-x:none}.workflow-editor[data-v-99bae5ed]{display:flex;flex-direction:column}.workflow-editor .title[data-v-99bae5ed]{display:flex;align-items:center;gap:10px}.workflow-editor .title:not(:hover) .edit-icon[data-v-99bae5ed]{display:none}.workflow-editor .title .edit-icon[data-v-99bae5ed]{cursor:pointer}.workflow-editor .workflow-editor-content[data-v-99bae5ed]{display:flex;flex-grow:1}.workflow-editor .workflow-editor-content .workflow-toolbar[data-v-99bae5ed]{display:flex;flex-direction:column;background-color:#fff;gap:10px;padding:10px;box-shadow:0 0 5px #0003}.workflow-editor .workflow-editor-content .workflow-toolbar .toolbar-item[data-v-99bae5ed]{cursor:grab}.workflow-editor .workflow-editor-content .workflow-toolbar .toolbar-item[data-v-99bae5ed]:hover{box-shadow:0 0 5px #0003;transform:rotate(-5deg)}.workflow-editor .canvas-container[data-v-99bae5ed]{flex-grow:1;flex-basis:0;position:relative;overflow:auto;outline:none}.workflow-editor .canvas-container[data-v-99bae5ed]:focus{border:2px solid #ebebeb}.workflow-editor .canvas-container .workflow-canvas[data-v-99bae5ed]{position:absolute;top:0;left:0;width:100%;height:100%;user-select:none;background-color:#fbfbfb}
