import"./outputWidgets.d94fff8c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="09f3905a-10aa-4cc3-9727-52d164001578",e._sentryDebugIdIdentifier="sentry-dbid-09f3905a-10aa-4cc3-9727-52d164001578")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.596d80c9.js.map
