import"./outputWidgets.d94fff8c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="d7ffaa21-cbf8-479c-929a-9191e4b8888c",e._sentryDebugIdIdentifier="sentry-dbid-d7ffaa21-cbf8-479c-929a-9191e4b8888c")}catch{}})();function c(e){return e.charAt(0).toUpperCase()+e.slice(1)}function s(e,r){const n=e.toLocaleLowerCase().replace(/[^a-z0-9]/g,"_").replace(/_+/g,"_");return r?n:n.replace(/_$/,"")}export{c,s as n};
//# sourceMappingURL=string.5dafdc8d.js.map
