import{x as t,b as s,eu as f}from"./outputWidgets.d94fff8c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="ffcbbc15-57d1-4000-9bfb-bbf6fa976118",e._sentryDebugIdIdentifier="sentry-dbid-ffcbbc15-57d1-4000-9bfb-bbf6fa976118")}catch{}})();const o={},r={class:"organization-settings"};function i(e,n){return s(),f("div",r,"Organization settings")}const d=t(o,[["render",i]]);export{d as default};
//# sourceMappingURL=OrganizationSettings.fe94b8bc.js.map
