import{x as o,a,b as i,c,g as d,h as p,_,i as u,T as f,j as l,P as b,C as h,M as m,s as y,k as s,l as g,m as v,n as w,p as I}from"./outputWidgets.d94fff8c.js";import{u as k}from"./index.7a77fb2c.js";import"./pubsub.39314a92.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9e75fa2e-b369-4db8-81fb-a6678004cd93",e._sentryDebugIdIdentifier="sentry-dbid-9e75fa2e-b369-4db8-81fb-a6678004cd93")}catch{}})();const x={};function A(e,t){const r=a("router-view");return i(),c(r,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const D=o(x,[["render",A]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.8b115284.js"),["assets/Player.8b115284.js","assets/index.3dad0da1.js","assets/outputWidgets.d94fff8c.js","assets/outputWidgets.f6e466ca.css","assets/uuid.fd17a681.js","assets/broker.44d4092d.js","assets/index.7a77fb2c.js","assets/pubsub.39314a92.js","assets/executeJs.99ff6d52.js","assets/icons.fec42461.js","assets/CircularLoading.8c280b78.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.7583d5f4.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.0a5e4246.js","assets/Steps.998aa76d.css","assets/executeJs.ee59d5a5.css","assets/WidgetsFrame.2f3ca3a1.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.4e98488d.js","assets/broker.1fe265d9.css","assets/DashPlayer.c01dbd8d.js","assets/geometryUtils.afddc11b.js","assets/DashPlayer.b0953bcd.css","assets/asyncComputed.6da48dd7.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class P{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await k();const e=u({render:()=>g(D)});f.init(),l(e,n),P.init(),e.use(n),e.use(b),e.mount("#app"),e.component("VSelect",h),e.component("Markdown",m),e.component("Message",y),s(e,v),s(e,w),s(e,I)})();
//# sourceMappingURL=player.7bef76c0.js.map
