import{B as p,e as f,a as o,c as h}from"./Title.c70c7e79.js";import{W as a,ad as T,f as g,R as l}from"./outputWidgets.d94fff8c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="f713dc81-a017-4f5a-ad5a-d4bb0eea5fe1",e._sentryDebugIdIdentifier="sentry-dbid-f713dc81-a017-4f5a-ad5a-d4bb0eea5fe1")}catch{}})();var w=globalThis&&globalThis.__rest||function(e,r){var s={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&r.indexOf(t)<0&&(s[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var n=0,t=Object.getOwnPropertySymbols(e);n<t.length;n++)r.indexOf(t[n])<0&&Object.prototype.propertyIsEnumerable.call(e,t[n])&&(s[t[n]]=e[t[n]]);return s};const A=()=>l(a(a({},f()),{ellipsis:{type:Boolean,default:void 0}}),["component"]),i=(e,r)=>{let{slots:s,attrs:t}=r;const n=a(a({},e),t),{ellipsis:y,rel:m}=n,b=w(n,["ellipsis","rel"]);T();const u=a(a({},b),{rel:m===void 0&&b.target==="_blank"?"noopener noreferrer":m,ellipsis:!!y,component:"a"});return delete u.navigate,g(p,u,s)};i.displayName="ATypographyLink";i.inheritAttrs=!1;i.props=A();const P=i,O=()=>l(f(),["component"]),d=(e,r)=>{let{slots:s,attrs:t}=r;const n=a(a(a({},e),{component:"div"}),t);return g(p,n,s)};d.displayName="ATypographyParagraph";d.inheritAttrs=!1;d.props=O();const x=d,k=()=>a(a({},l(f(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),c=(e,r)=>{let{slots:s,attrs:t}=r;const{ellipsis:n}=e;T();const y=a(a(a({},e),{ellipsis:n&&typeof n=="object"?l(n,["expandable","rows"]):n,component:"span"}),t);return g(p,y,s)};c.displayName="ATypographyText";c.inheritAttrs=!1;c.props=k();const _=c;o.Text=_;o.Title=h;o.Paragraph=x;o.Link=P;o.Base=p;o.install=function(e){return e.component(o.name,o),e.component(o.Text.displayName,_),e.component(o.Title.displayName,h),e.component(o.Paragraph.displayName,x),e.component(o.Link.displayName,P),e};export{x as A,P as L,_ as a};
//# sourceMappingURL=index.7d7e00b1.js.map
