import{d as u,eA as f,J as b,b as y,c as g,u as _}from"./outputWidgets.d94fff8c.js";import{a as w}from"./asyncComputed.6da48dd7.js";import"./router.4a188c48.js";import{M as n}from"./member.8f6fb06a.js";import"./index.a5166b6d.js";import{C as I}from"./CrudView.e6c5592c.js";import"./Title.c70c7e79.js";import"./index.3dad0da1.js";import"./gateway.8dd534ee.js";import"./activeRecord.4bb9e983.js";import"./pubsub.39314a92.js";import"./icons.fec42461.js";import"./index.7d7e00b1.js";import"./Form.57801503.js";import"./url.596d80c9.js";import"./index.e7f021ad.js";import"./index.3709b59d.js";import"./index.0f14f01f.js";import"./index.209f6c1c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="64cca2f6-f3eb-4d03-8e81-5b01502f3019",e._sentryDebugIdIdentifier="sentry-dbid-64cca2f6-f3eb-4d03-8e81-5b01502f3019")}catch{}})();const F=u({__name:"Members",setup(e){const r=f().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(r,t.email),p()},{loading:l,result:d,refetch:p}=w(()=>n.list(r)),c=b(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=d.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{F as default};
//# sourceMappingURL=Members.0a64d3a5.js.map
