import{S as c}from"./Sidebar.eeeb07b4.js";import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.94933484.js";import{G as d,H as l,I as u}from"./icons.fec42461.js";import{d as b,eA as f,J as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.d94fff8c.js";import{a as w}from"./asyncComputed.6da48dd7.js";import"./router.4a188c48.js";import{O as z}from"./organization.f12114ad.js";import"./index.a5166b6d.js";import{B as h}from"./BaseLayout.f1c5ada3.js";import"./Tooltip.53cc6f36.js";import"./logo.084e5d7c.js";import"./index.7d7e00b1.js";import"./Title.c70c7e79.js";import"./index.209f6c1c.js";import"./index.c81cf59e.js";import"./index.3dad0da1.js";import"./gateway.8dd534ee.js";import"./activeRecord.4bb9e983.js";import"./pubsub.39314a92.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="7ee3c407-dbc8-457e-9b88-1ca8545d86a3",e._sentryDebugIdIdentifier="sentry-dbid-7ee3c407-dbc8-457e-9b88-1ca8545d86a3")}catch{}})();const q=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(p,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(c,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{q as default};
//# sourceMappingURL=Organization.a1dab35f.js.map
