import{v as a}from"./icons.fec42461.js";import{d as c,a as r,b as d,eu as i,f,u as _,aJ as l,x as u}from"./outputWidgets.d94fff8c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="60faec27-0656-4014-926d-f9c667f57cd2",e._sentryDebugIdIdentifier="sentry-dbid-60faec27-0656-4014-926d-f9c667f57cd2")}catch{}})();const p=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=r("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[f(s,{class:"icon",path:_(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const v=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.49804c07.js.map
