import{C as n,A as t}from"./CollapsePanel.1d546a09.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="7ea1ed88-c73e-488f-bf19-ee3b5d186279",e._sentryDebugIdIdentifier="sentry-dbid-7ea1ed88-c73e-488f-bf19-ee3b5d186279")}catch{}})();n.Panel=t;n.install=function(e){return e.component(n.name,n),e.component(t.name,t),e};
//# sourceMappingURL=index.1978a0ba.js.map
