import"./outputWidgets.d94fff8c.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[d]="dbc9158b-64cd-49f6-a74a-fd0f9bca0ddc",x._sentryDebugIdIdentifier="sentry-dbid-dbc9158b-64cd-49f6-a74a-fd0f9bca0ddc")}catch{}})();const e=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const d=Math.random()*16|0;return(x=="x"?d:d&3|8).toString(16)}),r=()=>Math.random().toString(36).slice(2);export{r,e as u};
//# sourceMappingURL=uuid.fd17a681.js.map
