import"./outputWidgets.d94fff8c.js";import{M as r}from"./Title.c70c7e79.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e59aa9e5-6389-486d-bde9-fec0c73ae9ff",e._sentryDebugIdIdentifier="sentry-dbid-e59aa9e5-6389-486d-bde9-fec0c73ae9ff")}catch{}})();function f(e){switch(typeof e){case"object":return Object.entries(e).map(([t,n])=>({title:t,key:t,children:f(n)}));default:return[{title:e,key:e}]}}function a(e){return new Promise(t=>{r.confirm({title:e,onOk:()=>t(!0),onCancel:()=>t(!1)})})}export{a,f as t};
//# sourceMappingURL=ant-design.b0e50c8b.js.map
